EclipseWhereResult class

Return type for solEclipseWhere / lunOccultWhere.

Constructors

EclipseWhereResult({required double geolon, required double geolat, required double magnitude, required double diameterRatio, required double obscuration, required double coreShadowKm, required double sunAzimuth, required double sunTrueAltitude, required double sunApparentAltitude, required double moonSunAngle, required int returnFlag})
const

Properties

coreShadowKm double
final
diameterRatio double
final
geolat double
final
geolon double
final
hashCode int
The hash code for this object.
no setterinherited
magnitude double
final
moonSunAngle double
final
obscuration double
final
returnFlag int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sunApparentAltitude double
final
sunAzimuth double
final
sunTrueAltitude double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited